Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(660)

Unified Diff: pkg/analysis_server/lib/src/server/driver.dart

Issue 2634603002: Revert "Enable the new analysis driver by default, use --disable-new-analysis-driver to disable." (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analysis_server/test/integration/integration_tests.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/server/driver.dart
diff --git a/pkg/analysis_server/lib/src/server/driver.dart b/pkg/analysis_server/lib/src/server/driver.dart
index ea6074e7230f46bec9422c4db4c8223f8af4c603..072fa7506d193216a97e566b43019391ab67a657 100644
--- a/pkg/analysis_server/lib/src/server/driver.dart
+++ b/pkg/analysis_server/lib/src/server/driver.dart
@@ -242,10 +242,9 @@ class Driver implements ServerStarter {
"incremental-resolution-validation";
/**
* The name of the option used to disable using the new analysis driver.
*/
- static const String DISABLE_NEW_ANALYSIS_DRIVER =
- 'disable-new-analysis-driver';
+ static const String ENABLE_NEW_ANALYSIS_DRIVER = 'enable-new-analysis-driver';
/**
* The name of the option used to enable using pub summary manager.
@@ -394,7 +393,7 @@ class Driver implements ServerStarter {
analysisServerOptions.enableIncrementalResolutionValidation =
results[INCREMENTAL_RESOLUTION_VALIDATION];
analysisServerOptions.enableNewAnalysisDriver =
- !results[DISABLE_NEW_ANALYSIS_DRIVER];
+ results[ENABLE_NEW_ANALYSIS_DRIVER];
analysisServerOptions.enablePubSummaryManager =
results[ENABLE_PUB_SUMMARY_MANAGER];
analysisServerOptions.finerGrainedInvalidation =
@@ -544,8 +543,8 @@ class Driver implements ServerStarter {
help: "enable validation of incremental resolution results (slow)",
defaultsTo: false,
negatable: false);
- parser.addFlag(DISABLE_NEW_ANALYSIS_DRIVER,
- help: "disable using new analysis driver",
+ parser.addFlag(ENABLE_NEW_ANALYSIS_DRIVER,
+ help: "enable using new analysis driver",
defaultsTo: false,
negatable: false);
parser.addFlag(ENABLE_PUB_SUMMARY_MANAGER,
@@ -242,10 +242,9 @@ class Driver implements ServerStarter {
"incremental-resolution-validation";
/**
- * The name of the option used to disable using the new analysis driver.
+ * The name of the option used to enable using the new analysis driver.
*/
« no previous file with comments | « no previous file | pkg/analysis_server/test/integration/integration_tests.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698